AwacConfig

Struct AwacConfig 

pub struct AwacConfig<Q, P>{
Show 16 fields pub actor_config: GaussianActorConfig<P::Config>, pub critic_config: MultiCriticConfig<Q::Config>, pub gamma: f64, pub inv_lambda: f64, pub tau: f64, pub min_lstd: f64, pub max_lstd: f64, pub n_updates_per_opt: usize, pub batch_size: usize, pub critic_loss: CriticLoss, pub reward_scale: f32, pub n_critics: usize, pub exp_adv_max: f64, pub seed: Option<i64>, pub device: Option<Device>, pub adv_softmax: bool,
}
Configuration of Awac.

Fields

actor_config: GaussianActorConfig<P::Config>

Configuration of the actor model.

critic_config: MultiCriticConfig<Q::Config>

Configuration of the critic model.

gamma: f64

Discont factor.

inv_lambda: f64

The inverse of lambda in the paper.

tau: f64

Target smoothing coefficient.

This is a real number between 0 and 1. A value of 0.001 makes the target network parameters adapt very slowly to the critic network parameters.

Formula: target_params = tau * critic_params + (1.0 - tau) * target_params

min_lstd: f64

Minimum value of the log of the standard deviation of the action distribution.

max_lstd: f64

Maximum value of the log of the standard deviation of the action distribution.

n_updates_per_opt: usize

Number of parameter updates per optimization step.

batch_size: usize

Batch size for training.

critic_loss: CriticLoss

Type of critic loss function.

reward_scale: f32

Scaling factor for rewards.

n_critics: usize

Number of critics used.

exp_adv_max: f64

Maximum of exponent of advantage.

seed: Option<i64>

Random seed value (optional).

device: Option<Device>

Device used for the actor and critic models (e.g., CPU or GPU).

adv_softmax: bool

If true, advantage weights are calculated with softmax within each mini-batch.

Implementations

Source

impl<Q, P> AwacConfig<Q, P>

pub fn lambda(self, v: f64) -> Self

Sets lambda.

pub fn n_updates_per_opt(self, v: usize) -> Self

Sets the numper of parameter update steps per optimization step.

pub fn batch_size(self, v: usize) -> Self

Batch size.

pub fn discount_factor(self, v: f64) -> Self

Discount factor.

pub fn tau(self, v: f64) -> Self

Sets soft update coefficient.

pub fn reward_scale(self, v: f32) -> Self

Reward scale.

It works for obtaining target values, not the values in logs.

pub fn critic_loss(self, v: CriticLoss) -> Self

Critic loss.

pub fn actor_config(self, actor_config: GaussianActorConfig<P::Config>) -> Self

Configuration of actor.

pub fn critic_config(self, critic_config: MultiCriticConfig<Q::Config>) -> Self

Configuration of critic.

pub fn n_critics(self, n_critics: usize) -> Self

The number of critics.

pub fn seed(self, seed: i64) -> Self

Random seed.

pub fn device(self, device: Device) -> Self

Device.

pub fn adv_softmax(self, b: bool) -> Self

If true, advantage weights are calculated with softmax within each mini-batch.

pub fn load(path: impl AsRef<Path>) -> Result<Self>

Constructs AwacConfig from YAML file.

pub fn save(&self, path: impl AsRef<Path>) -> Result<()>

Saves AwacConfig to YAML file.