pub struct BcModelConfig<C>{
pub policy_model_config: Option<C>,
pub opt_config: OptimizerConfig,
}Expand description
Configuration of BcModel.
The type parameter C should be a configuration of policy model, which should outputs a tensor.
The policy model supports both discrete and continuous action spaces, leaving the interpretation
of the output to the caller.
Fields
policy_model_config: Option<C>opt_config: OptimizerConfigImplementations
Sourceimpl<C> BcModelConfig<C>
impl<C> BcModelConfig<C>
Sourcepub fn policy_model_config(self, v: C) -> Self
pub fn policy_model_config(self, v: C) -> Self
Sets configurations for the policy model.
Sourcepub fn opt_config(self, v: OptimizerConfig) -> Self
pub fn opt_config(self, v: OptimizerConfig) -> Self
Sets optimizer configuration.