pub struct IqlConfig<Q, P, V>where
Q: SubModel2<Output = Tensor>,
P: SubModel1<Output = (Tensor, Tensor)>,
V: SubModel1<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,
P::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,
V::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,{
pub value_config: ValueConfig<V::Config>,
pub critic_config: MultiCriticConfig<Q::Config>,
pub actor_config: GaussianActorConfig<P::Config>,
pub gamma: f32,
pub tau_iql: f64,
pub inv_lambda: f64,
pub n_updates_per_opt: usize,
pub batch_size: usize,
pub adv_softmax: bool,
pub critic_loss: CriticLoss,
pub device: Option<Device>,
pub exp_adv_max: f64,
}Expand description
Configuration of Iql.
Fields
value_config: ValueConfig<V::Config>Configuration of the value model.
critic_config: MultiCriticConfig<Q::Config>Configuration of the critic model.
actor_config: GaussianActorConfig<P::Config>Configuration of the actor model.
gamma: f32Discont factor.
tau_iql: f64Expectile value.
inv_lambda: f64The inverse of lambda in the paper.
n_updates_per_opt: usizeNumber of parameter updates per optimization step.
batch_size: usizeBatch size for training.
adv_softmax: boolIf true, advantage weights are calculated with softmax within each mini-batch.
critic_loss: CriticLossType of critic loss function.
device: Option<Device>Device used for the actor and critic models (e.g., CPU or GPU).
exp_adv_max: f64Maximum of exponent of advantage.
Implementations
Sourceimpl<Q, P, V> IqlConfig<Q, P, V>where
Q: SubModel2<Output = Tensor>,
P: SubModel1<Output = (Tensor, Tensor)>,
V: SubModel1<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,
P::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,
V::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,
impl<Q, P, V> IqlConfig<Q, P, V>where
Q: SubModel2<Output = Tensor>,
P: SubModel1<Output = (Tensor, Tensor)>,
V: SubModel1<Output = Tensor>,
Q::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,
P::Config: DeserializeOwned + Serialize + OutDim + Debug + PartialEq + Clone,
V::Config: DeserializeOwned + Serialize + Debug + PartialEq + Clone,
Sourcepub fn n_updates_per_opt(self, v: usize) -> Self
pub fn n_updates_per_opt(self, v: usize) -> Self
Sets the numper of parameter update steps per optimization step.
Sourcepub fn batch_size(self, v: usize) -> Self
pub fn batch_size(self, v: usize) -> Self
Batch size.
Sourcepub fn discount_factor(self, v: f32) -> Self
pub fn discount_factor(self, v: f32) -> Self
Discount factor.
Sourcepub fn critic_loss(self, v: CriticLoss) -> Self
pub fn critic_loss(self, v: CriticLoss) -> Self
Critic loss.
Sourcepub fn value_config(self, value_config: ValueConfig<V::Config>) -> Self
pub fn value_config(self, value_config: ValueConfig<V::Config>) -> Self
Configuration of value function.
Sourcepub fn actor_config(self, actor_config: GaussianActorConfig<P::Config>) -> Self
pub fn actor_config(self, actor_config: GaussianActorConfig<P::Config>) -> Self
Configuration of actor.
Sourcepub fn critic_config(self, critic_config: MultiCriticConfig<Q::Config>) -> Self
pub fn critic_config(self, critic_config: MultiCriticConfig<Q::Config>) -> Self
Configuration of critic.
Sourcepub fn adv_softmax(self, b: bool) -> Self
pub fn adv_softmax(self, b: bool) -> Self
If true, advantage weights are calculated with softmax within each mini-batch.