pub struct GaussianActor<P>where
P: SubModel1<Output = (Tensor, Tensor)>,
P::Config: DeserializeOwned + Serialize + OutDim + Clone,{ /* private fields */ }Expand description
Actor with Gaussian policy.
Implementations
Sourceimpl<P> GaussianActor<P>
impl<P> GaussianActor<P>
Sourcepub fn build(
config: GaussianActorConfig<P::Config>,
device: Device,
) -> Result<GaussianActor<P>>
pub fn build( config: GaussianActorConfig<P::Config>, device: Device, ) -> Result<GaussianActor<P>>
Constructs GaussianActor.
Sourcepub fn forward(&self, x: &P::Input) -> (Tensor, Tensor)
pub fn forward(&self, x: &P::Input) -> (Tensor, Tensor)
Returns the parameters of Gaussian distribution given an observation.
The type of return values is (Tensor, Tensor).
The shape of the both tensors is (batch_size, action_dimension).
Sourcepub fn logp<'a>(&self, obs: &P::Input, act: &Tensor) -> Result<Tensor>
pub fn logp<'a>(&self, obs: &P::Input, act: &Tensor) -> Result<Tensor>
Rerurns the log probabilities (densities) of the given actions
Sourcepub fn sample(&mut self, obs: &P::Input, train: bool) -> Result<Tensor>
pub fn sample(&mut self, obs: &P::Input, train: bool) -> Result<Tensor>
Samples actions.
If train is true, actions are sampled from a Gaussian distribution.
Otherwise, the mean of the Gaussian distribution is returned.
pub fn backward_step(&mut self, loss: &Tensor) -> Result<()>